util

package
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 25, 2022 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var ErrInvalidFormat = errors.New("cgroups: parsing file with invalid format failed")

Functions

func GetContentFromCGroupFile

func GetContentFromCGroupFile(filename string) int

func IsContainer

func IsContainer() bool

func ParseKV

func ParseKV(raw string) (string, uint64, error)

func ReadContent

func ReadContent(filename string) (string, error)

ReadContent reads contents from a file

func ReadLines

func ReadLines(filename string) ([]string, error)

ReadLines reads contents from a file and splits them by new lines. A convenience wrapper to ReadLinesOffsetN(filename, 0, -1).

func ReadLinesOffsetN

func ReadLinesOffsetN(filename string, offset uint, n int) ([]string, error)

ReadLinesOffsetN reads contents from file and splits them by new line. The offset tells at which line number to start. The count determines the number of lines to read (starting from offset):

n >= 0: at most n lines
n < 0: whole file

Types

This section is empty.

Jump to