Documentation
¶
Index ¶
- Variables
- func GetContentFromCGroupFile(filename string) int
- func IsContainer() bool
- func ParseKV(raw string) (string, uint64, error)
- func ReadContent(filename string) (string, error)
- func ReadLines(filename string) ([]string, error)
- func ReadLinesOffsetN(filename string, offset uint, n int) ([]string, error)
Constants ¶
This section is empty.
Variables ¶
var ErrInvalidFormat = errors.New("cgroups: parsing file with invalid format failed")
Functions ¶
func IsContainer ¶
func IsContainer() bool
func ReadContent ¶
ReadContent reads contents from a file
func ReadLines ¶
ReadLines reads contents from a file and splits them by new lines. A convenience wrapper to ReadLinesOffsetN(filename, 0, -1).
func ReadLinesOffsetN ¶
ReadLinesOffsetN reads contents from file and splits them by new line. The offset tells at which line number to start. The count determines the number of lines to read (starting from offset):
n >= 0: at most n lines n < 0: whole file
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.